C      3/31/2000
      SUBROUTINE STAT(N,X,Y,XMEAN,YMEAN,RMEAN,SDX,SDY,SDR,R,A,B,SEEST,
     +SX,SY,SQX,SQY,SXY,Z,NS,XMAX,YMAX,resmax,IOP,XMIN,YMIN)
      REAL X(1),Y(1)
      INTEGER Z(1)
C     ***********************************************************************
C  This version inputs the observations and calculates the sums and sums of squares
C      DOUBLE PRECISION SX,SY,SQX,SQY,SXY,SR,SQR
C     ***********************************************************************
C     N, X and Y are only inputs to this subroutine. The rest are outputs.
C     ***********************************************************************
C     SX,SY,SQX,SQY,SXY are sums, sums of squares and sum of product
C     N is length of series x and y
C     X is estimate, Y is actual data
C     R is correlation coefficient, RM is mean square of mean residual
C     RV is mean square of departures of residual from mean
C     to obtain total variance, RM and RV must be summed
C     SDY, SDX, SDR are standard deviations of Y, X, Residuals
C     B, A, SEEST are regression equation of Y on X and standard error of est
      NS=0.0    !The following accumulators are set to zero
      XMEAN=0.0
      YMEAN=0.0
      RMEAN=0.0
      SDX=0.0
      SDY=0.0
      SDR=0.0
      R=0.0
      A=0.0
      B=0.0
      SEEST=0.0
      SX=0
      SY=0
      SQX=0
      SQY=0
      SXY=0
      SR=0
      SQR=0
      BARN=0
      XMAX=0
      YMAX=0
	XMIN=99999.
	YMIN=99999.
      RESMAX=0
C
      DO 10 I=1,N    ! Do over number of observations (N)
       IF(Z(I).EQ.0)GOTO 10   ! Z=0 when the following are already calculated
       NS=NS+1         ! Number of observations
       SX=SX+X(I)      ! Sum of X variable
       IF(XMAX.LT.X(I))XMAX=X(I) ! Max for X calculated
       IF(XMIN.GT.X(I))XMIN=X(I) ! Max for X calculated
       SY=SY+Y(I)      ! Sum of Y variable
       IF(YMAX.LT.Y(I))YMAX=Y(I) ! Max for Y calculated
       IF(YMIN.GT.Y(I))YMIN=Y(I) ! Max for Y calculated
       SQX=SQX+X(I)**2 ! Sum of squares of X variable
       SQY=SQY+Y(I)**2 ! Sum of squares of Y variable
       SXY=SXY+X(I)*Y(I) ! Cross product term (Sum of X times Y)
       SR=SR+(Y(I)-X(I)) ! Sum of differences between X and Y
       IF(RESMAX.LT.ABS(X(I)-Y(I)))RESMAX=ABS(X(I)-Y(I))
       SQR=SQR+((Y(I)-X(I))**2) ! Square of differences X and Y
10    CONTINUE
      IF(NS.GT.0)THEN
        IF(NS.GT.1)THEN
          XNS=NS
	    XX=XNS/(XNS-1)
 	    BARN=SQRT(XX) !Used to adjust SD for sample size
        ENDIF
        XMEAN=SX/NS   ! Mean of X variable
        YMEAN=SY/NS   ! Mean of Y variable
        RMEAN=SR/NS   ! Mean of differences between X and Y  (Residuals)
        IF(SQY/NS-YMEAN**2.GT.0)SDY=SQRT(SQY/NS-YMEAN**2) ! St Dev of Y var
        IF(SQX/NS-XMEAN**2.GT.0)SDX=SQRT(SQX/NS-XMEAN**2) ! St Dev of X var
        SUMxy=SXY-(NS*YMEAN*XMEAN)! Sum of Crossproducts corrected for means
        RV=SQR/NS-RMEAN**2                        ! Mean Square of Residuals
        IF(SDX*SDY.GT.0.AND.NS.GT.2)THEN
          IF(RV.GT.0)THEN
            SDR=SQRT(RV) !Standard Deviation of Residuals
          ENDIF
          R=SUMxy/(NS*SDX*SDY) ! Correlation (R) Coefficient between X and Y
          RBAR=1.0-((1.0-R**2)*(NS-1)/(NS-2))! R corrected for sample size
          B=SUMxy/(NS*SDX**2)  ! Regression slope for Y on X
          A=YMEAN-(B*XMEAN)    ! Y intercept for regression line
        ENDIF
        IF(SDX.GT.0)SDX=SDX*BARN
        IF(SDY.GT.0)SDY=SDY*BARN
      ENDIF
      SDZ=(SDY**2)*(1-RBAR)
      IF(SDZ.GT.0)SEEST=SQRT(SDZ) ! Standard error of estimate
      XX=N*XMEAN*YMEAN*SDX*SDY*SDR*R*B*SEEST*NS
      IF(XX.EQ.0)WRITE(*,'('' One or more output values from program ''
     +,''STAT are zero.'')')
101   FORMAT(/' N,XMEAN,YMEAN,RMEAN,SDX,SDY,SDR'/ I4
     +,6F10.4/' R,RBAR,A,B,SEEST'/1X,5F10.3/
     +' SX,SY,SQX,SQY,SXY'/1X,5F12.2/' SR,SQR'/2F10.2)
c       IF(IOP.EQ.3)WRITE(31,101)N,XMEAN,YMEAN,RMEAN,SDX,SDY,SDR,R,RBAR,
c     +A,B,SEEST,SX,SY,SQX,SQY,SXY,SR,SQR
       RETURN
      END

      SUBROUTINE STAT2(N,XMEAN,YMEAN,RMEAN,SDX,SDY,SDR,R,A,B,SEEST,
     +SX,SY,SQX,SQY,SXY,SR,SQR,IOP)
      REAL N
C     ***********************************************************************
C This stat version inputs the sums and sums of squares rather than observations
C     N,SX,SY,SQX,SQY,SXY are inputs to this subroutine. The rest are outputs.
C     (Note that Stat inputs are only the variables themselves while Stat2
C      requires the sums, sums of squares, and cross products as inputs)
C     ***********************************************************************
C     SX,SY,SQX,SQY,SXY are sums, sums of squares and sum of product
C     SR, SRSQ are sums, sums of squares of Y-X
C     N is length of series x and y
C     X is estimate, Y is actual data
C     R is correlation coefficient, RM is mean square of mean residual
C     RV is mean square of residual
C     to obtain total variance, RM and RV must be summed
C     SDY, SDX, SDR are standard deviations of Y, X, Residuals
C     B, A, SEEST are regression equation of Y on X and standard error of est
       XMEAN=0.0
       YMEAN=0.0
       RMEAN=0.0
       SDX=0.0
       SDY=0.0
       SDR=0.0
       R=0.0
       A=0.0
       B=0.0
       SEEST=0.0
       BARN=0
       IF(N.GT.0)THEN
        IF(N.GT.1.0)BARN=SQRT(N/(N-1.)) !Used to adjust SD for sample size
        XMEAN=SX/N ! Mean of X
        YMEAN=SY/N ! Mean of Y
        RMEAN=SR/N ! Mean of residuals (X-Y)
        IF(SQY/N-YMEAN**2.GT.0)SDY=SQRT(SQY/N-YMEAN**2) ! Standard Deviation of Y
        IF(SQX/N-XMEAN**2.GT.0)SDX=SQRT(SQX/N-XMEAN**2) ! Standard Deviation of X
        SUMxy=SXY-(N*YMEAN*XMEAN)! Sum of Crossproducts corrected for means
        RV=SQR/N-RMEAN**2                        ! Mean Square of Residuals
        IF(SDX*SDY.GT.0.AND.N.GT.2.0)THEN
          IF(RV.GT.0)THEN
            SDR=SQRT(RV) !Standard Deviation of Residuals
          ENDIF
          R=SUMxy/(N*SDX*SDY)       ! Correlation Coefficient
          RBAR=1.0-((1.0-R**2)*(N-1)/(N-2))! R corrected for sample size
          B=SUMxy/(N*SDX**2)        ! Regression Coefficient of Y on X
          A=YMEAN-(B*XMEAN)         ! Y intercept of regression of Y on X
        ENDIF
        IF(SDX.GT.0)SDX=SDX*BARN
        IF(SDY.GT.0)SDY=SDY*BARN
        SDZ=(SDY**2)*(1-RBAR)
        IF(SDZ.GT.0)SEEST=SQRT(SDZ)
      ENDIF
101   FORMAT(/' N,XMEAN,YMEAN,RMEAN,SDX,SDY,SDR,'/
     +,7F10.4,/,' R,RBAR,A,B,SEEST,'/1X,5F10.3,/,
     +' SX,SY,SQX,SQY,SXY,',/,1X,5F12.2,/,' SR,SQR',/,2F10.2)
c      IF(IOP.EQ.3)WRITE(31,101)N,XMEAN,YMEAN,RMEAN,SDX,SDY,SDR,R,RBAR,
c     +A,B,SEEST,SX,SY,SQX,SQY,SXY,SR,SQR
      XX=N*XMEAN*YMEAN*SDX*SDY*SDR*R*B*SEEST
      IF(XX.EQ.0)WRITE(*,'('' One or more output values from program ''
     +,''STAT2 are zero.'')')
      RETURN
      END

      SUBROUTINE NORMAL(n,trach,nnor,op)
c Ŀ
c   subroutine for calculation  normolized trach                
c   trach()  - input trach, output nortrach                     
c   n        - number of cells of the trach                     
c   nnor     - number of cells of the nortrach                  
c 
      REAL    trach(1000),t(1000)
      INTEGER op(40)
	DO I=1,1000
	  IF(I.LE.N)THEN
          IF(I.GT.1.AND.TRACH(I).EQ.0)TRACH(I)=TRACH(I-1)
	  ELSE
	    trach(i)=0.
	  ENDIF  
	ENDDO
	DO I=1,1000
	  t(i)=0.
	ENDDO
      DO i=1,nnor
       s=0
       l1=(i-1)*n+1
       l2=i*n
		DO ii=l1,l2
       k=INT((ii-1)/nnor)+1
       s=s+trach(k)
		END DO
      t(i)=s/n     ! correction of trw (NR(j)
      END DO
      IF(op(12).EQ.2.AND.op(13).NE.1)THEN
	  if(n.gt.nnor)then
	   DO i=1,n
          if(t(i).eq.0.and.i.gt.1.and.i.le.nnor)then
	      t(i)=t(i-1)
	    endif
	    IF(I.EQ.1)WRITE(60,'(/'' UNNORMALIZED NUMBER'',I4,
     +    ''    NORMALIZED NUMBER'',I4)')n,nnor
          WRITE(60,'('' NUMBER '',I3,'' UNNORMALIZED '',F10.5,
     +    ''    NORMALIZED '',F10.5)')i,trach(i),t(i)
	   ENDDO
	  else
	   DO i=1,nnor
	    if(t(i).eq.0.and.i.gt.1)then
	      t(i)=t(i-1)
	    endif
	    IF(I.EQ.1)WRITE(60,'(/'' UNNORMALIZED NUMBER'',I4,
     +    ''    NORMALIZED NUMBER'',I4)')n,nnor
          WRITE(60,'('' NUMBER '',I3,'' UNNORMALIZED '',F10.5,
     +    ''    NORMALIZED '',F10.5)')i,trach(i),t(i)
	   ENDDO
	  endif
	ENDIF
      DO i=1,nnor
	  if(t(i).eq.0.and.i.gt.1)then
	    t(i)=t(i-1)
	  endif
        trach(i)=t(i)
     
      END DO
      RETURN
      END

      subroutine datetime(ifile)
c      program datetime
CC    TTIME.FOR
CC    Tests GETDAT, GETTIM

C       INCLUDE   'FLIB.FI'
C       INCLUDE   'FLIB.FD'

c      INTERFACE TO SUBROUTINE SHOWDATE(year, month, day)
c      INTEGER*2 year, month, day
c      END

c      INTERFACE TO SUBROUTINE SHOWTIME(hour, minute, second, hund)
c      INTEGER*2 hour, minute, second, hund
c      END


      INTEGER*2 tmpday, tmpmonth, tmpyear
      INTEGER*2 tmphour, tmpminute, tmpsecond, tmphund
c      INTEGER*4
c      LOGICAL*4  success
c      ifile=10
C      open(10,file='timedate.dat')
      tmphund = 0
C
C     Show current date and time.
C
      WRITE (ifile,'('' Current date and time...'',\)')
c10    FORMAT(' Current date and time...',\)
      CALL GETDAT(tmpyear, tmpmonth, tmpday)
      CALL GETTIM(tmphour, tmpminute, tmpsecond, tmphund)
      CALL SHOWDATE(tmpyear, tmpmonth, tmpday,ifile)
      CALL SHOWTIME(tmphour, tmpminute, tmpsecond, tmphund,ifile)
      RETURN
      end


      SUBROUTINE SHOWDATE(year, month, day, ifile)
      INTEGER*2 year, month, day

      WRITE (ifile, 9001) month, day, year

9001  FORMAT (2x,I2, '/', I2.2, '/', I4.4,\)
      RETURN
      END

      SUBROUTINE SHOWTIME(hour, minute, second, hund,ifile)
      INTEGER*2 hour, minute, second, hund, thour

      CHARACTER*1 ap

      IF (hour .GT. 12) THEN
         ap = 'p'
         thour = hour - 12
      ELSE
         thour = hour
         ap = 'a'
      ENDIF

      WRITE (ifile, 9002) hour, minute, second, hund

9002  FORMAT (2x,I2, ':', I2.2, ':', I2.2, ':', I2.2, ' ', A, 'm')
      RETURN
      END


*RTN TRRW: Read/write measurements/indices
*
* Programmed (C) JUN 1984 by
* Richard L Holmes, University of Arizona, Tucson, Arizona  85721  USA
* Modified (C) 29 NOV 1993
* Made to read Indices only by H. C. Fritts  Feb. 25, 1994
* Read or write tree-ring measurements or indices in standard formats of the
* International Tree-Ring Data Bank (ITRDB)
* Measurements may be read in the ITRDB format (precision .01 mm, flag = 999)
* and the TRL-LDEO format (precision .001 mm, flag = -9999)
*
*   CALL TRRW(ID,N,Y,JYR,IO,NOIN)
*
* ID:    Series identification
*           6 characters for indices, 8 for measurements; string may be
*           longer.
* N:     Number of data values in series
* Y:     Array of index or measurement values
* JYR: Starting year of series
* IO:  Unit for reading or writing data
* NOIN:Number of years to be read
*
*
      SUBROUTINE TRRW(ID,N,Y,JYR,IO,NOIN,OP)
      CHARACTER ID*(*),IDA*6,LIN*80
      INTEGER DECADE,OP(40)
      REAL Y(1),YD(10)
*
*    File is already opened
c      IF(op(13).NE.1)OPEN(55,FILE='CHRONOLG.DAT')
      OPEN(55,FILE='CHRONOLG.DAT')
* Find the beginning decade
      DECADE=(JYR/10)*10
      LL=JYR-DECADE+1  !LL IS BEGINNING YEAR WITHIN DECADE
      N=0
      ISW=1
      IER=0
c      Write(*,'('' Title of Data: '')')
* Read line from file
      GOTO 1
   91 IER=IER+1
      IF(IER .GT. 25)STOP'>> Sbr TRRW:  No data in 25 lines'
      WRITE(*,'(1X,A)')LIN(:79)
    1 READ(IO,'(A)',ERR=99,END=99)LIN
      IF(LARGO(LIN) .LE. 8)GOTO 1
*
* Read indices
      READ(LIN,'(A,T7,I4,10(F4.3,3X))',ERR=91,END=99)!Reads line
     +IDA,JYR1,(YD(I),I=1,10)
      L=1
      IF(ISW .EQ. 1)THEN
        IF(JYR1.LT.DECADE) GOTO 1
        ID(:6)=IDA(:6)
        ISW=ISW+1
        L=LL  !L IS FIRST YEAR TO READ IN DECADE
C        IF(ISW.EQ.2)IYEAR=JYR1+L-1
      ENDIF
      DO 10 I=L,10
      NY=JYR+N
      N=N+1
      IF(N.GT.NOIN)THEN
        N=N-1
C        CLOSE(55)
        RETURN
      ENDIF
      
      IF(YD(I).GE. 9.90)THEN
      IF(op(13).NE.1)WRITE(55,'(I5,'' Missing Index Value - Greater Than
     + 9.90'')')NY
C        WRITE(*,'(I5,'' Missing Index Value - Greater Than 9.90''
C     +  )')NY
      ELSE
        Y(N)=YD(I)
      WRITE(55,'('' Year: '',I4,'' Number:''I3,''  Index:
     +'',F7.3)')NY,N,Y(N)
      ENDIF
   10 CONTINUE
      GOTO 1
   99 PAUSE ' READING ERROR OR END OF FILE IN INDEXED CHRONOLOGY DATA!' 
      WRITE(*,'('' READING ERROR OR END OF FILE IN INDEXED '',
     +''CHRONOLOGY DATA!'')')
C      CLOSE(55)
      RETURN
      END  
      
*RTN LARGO: Position of last non-blank character in string
*
* Programmed (C) FEB 1991 by
* Richard L Holmes, University of Arizona, Tucson, Arizona  85721  USA
* Modified (C) 01 DEC 1992
*
      FUNCTION LARGO(C)
      CHARACTER C*(*)
      LL=LEN(C)
      DO J=LL,1,-1
      K=ICHAR(C(J:J))
      IF(K .NE. 32 .AND. K .NE. 0)THEN
      LARGO=J
      RETURN
      ENDIF
      ENDDO ! J loop
      LARGO=1
      END ! LARGO
      
