C ********************************************************************
C     POTENTIAL TRANSPIRATION
C ********************************************************************    
      SUBROUTINE tran(p,Dlen,trp,sm,Mleaf,MFroot,RW,sowab,stwab,
     +                depth,sarea,volume,stemw)
c The calculation of stomatal resistence RW from water balance
c The source of water for transpiration is soil water (sowab)
c and water stored in stem (rate of loss - stwab).
c The max water storage is volume*(1-dsw/dw) - Waring&Running,1978.

c Mleaf is the foliage dry weight (DW)
c MFroot is the fine root DW
c Dlen is the daylength (h)
c trp is the potential rate of transpiration =D/Rmin (kg/m^2/h)
c sm is the soil moisture
c depth and sarea, are the depth and area of soil occupied by roots
c volume, is the volume of sapwood
c stemw is the concentration of water in the stem
c sowab is the flux of water from soil (kg/dm^3/h)
c stwab is the flux of water from stem storage 
c sowab and stwab calculated here only for resistence 
      REAL       p(60)
      REAL       Mleaf,MFroot,Dlen,trp,RW
      REAL       sm,depth,sarea 
	trp=trp*Dlen*Mleaf*p(3)
c flux from soil (kg/day/crown)
      soilwmax=(sm-p(9))*sarea*depth*1000.0 
      sowab=Dlen*p(18)*MFroot*TFUNC(sm,p(9),p(10),p(11),p(12))
      sowab=MIN(soilwmax,sowab) 
c flux from stem storage
      stwab=Dlen*p(43)*TFUNC(stemw,p(41),p(42),0.9,1.0)
	stwab=MIN(volume*1000.0*(stemw-p(41)),stwab) 
	sumw=sowab+stwab
c resistance from flux balance
	IF(sumw.GT.0.0)THEN
        RW=p(4)*trp/sumw
        IF(RW.LE.p(4))RW=p(4)
        IF(RW.GT.p(5))RW=p(5)
      ELSE
        RW=p(5)                 
      ENDIF
	RETURN 
	END
C ********************************************************************
C
C
C ********************************************************************
C     ACTUAL TRANSPIRATION
C ********************************************************************
      SUBROUTINE TRANS01(wddef,trp,Rmin)
      REAL wddef(366),trp(366)
      DO i=1,365
        trp(i)=wddef(i)/Rmin*3600.0  !First Deficit of Trans density water air
c                                 divided by min stomatal resistance p(4)
      END DO
      RETURN
      END
C ********************************************************************
C
C
C ********************************************************************
C     WATER BALANCE
C ********************************************************************
      SUBROUTINE water(p,sm,Prec,sowab,stwab,Transp,t,depth,sarea,
     +                 volume,stemw,Dlen,dgrmin,dgrmax)

      REAL       p(60),sm(366),stemw(366)
	REAL       Prec,depth,sarea,volume,sowab,stwab,dlen,
     +           dgrmin,dgrmax 
      INTEGER    t
      vol=volume*1000.0 !Convert to dm^3, 1 kg water ccupies 1 dm^3
c losses of the water from the stem storage
      stwab=MIN(stwab,Transp)
      stwab2=stwab
      dgrmin=MAX(p(41),stemw(t)-stwab2/vol)
c dgrmin is equal the stem water contents in the end of lightday	
c the rate of rechage the storage is determinated by water
c potential difference between storage (wp_stem) and soil (wo_soil)
c It is assumed that at saturation, sapwood water potential
c is the same as at field capacity of soil
      wp_soil=(sm(t)-p(9))/(p(13)-p(9))    !Percent
	wp_stem=(dgrmin-p(41))/(p(42)-p(41)) !Percent
	grad=MAX(0.0,wp_soil-wp_stem)
c the maximun recharge storage can be:
      recharge=MAX(0.0,(wp_soil*(p(42)-p(41))+p(41)-dgrmin)*vol)
c the night absorption of water is soil-to-stem     
	soil_to_stem=MIN(recharge,p(44)*grad*sowab*(24.0-Dlen)/Dlen)
      stemw(t+1)=dgrmin+soil_to_stem/vol
      dgrmax=stemw(t+1)
c losses of the water from the soil
      sowab=MIN(sowab,Transp-stwab)+soil_to_stem
c input water into soil from precipitation
      F=sarea*MIN(Prec*p(16),p(17))
c water in the soil
      sm(t+1)=sm(t)*(1-p(40))+(F-sowab)/(depth*sarea*1000.0)
      sm(t+1)=MAX(p(9),sm(t+1))
	sm(t+1)=MIN(sm(t+1),p(13))
      RETURN
      END
C ********************************************************************
C
C
C ********************************************************************    
C     PHOTOSYNTHESIS
C ********************************************************************    
      SUBROUTINE phsyn(p,Temp,Rad,Dlen,Phot,Mleaf,Pmax,ResWb,CO2i,Ca,R)
      REAL       p(60)
      REAL       Mleaf
c PT is relative temperature limitation on photosynthesis (0-1)
      PT=TFUNC(Temp,p(21),p(22),p(23),p(24)) !temperature function
      R= ResWb              ! R - leaf resistance due to water balance
c ResWb defined in Water balance subroutine
      PL=Rad/(Rad+p(2))    ! light Michales Mention function
      PM=Pmax*PT*PL     ! photosynthesis limited by temp and radiation
      x= PM*p(19)*R  ! PM*coeff for diffusion of CO2 rel to water*resi
      IF(x.LE.Ca-p(27))THEN ! If LT diff between CO2 in air & CO2 sat
        IF(PM.EQ.0)THEN  ! If limitation by temp and radiation is 0
          R=p(5)               ! Leaf resistance set at maximum
        ELSE           ! If limitation by temp and radiation is not 0
c R=CO2 gradient/limitation(temp,light)/coeff of diffu relative to H20
          R=(Ca-p(27))/PM/p(19) 
        END IF
        CO2i=p(27)         !CO2(inside) is saturated
        IF(R.GE.p(5))THEN  !If Resistance exceeds max
          R=p(5)                !Sets R at max
c Defines CO2(inside) as CO2 difference*coeff of diffusion rel to H20
c  *max resistance
          CO2i=Ca-PM*p(19)*R 
        END IF    ! If resistance does not exceed max resistance
c Photo = MAX photosynthesis limited by temp and radiation        
        Phot=PM
      ELSE  ! If Resistance NOT LT diff between CO2 in air & CO2 satura
c CO2(inside)=[sat CO2-Min CO2i(compensat)*CO2 in air +[Compensat Pt*x]
c / [sat CO2-Min CO2i(compensation)+x]
c Photo=[photosyn limited by temp and radiat*(CO2(inside)-Min CO2i
c / [sat CO2-Min CO2i]
          CO2i=((p(27)-p(26))*Ca+p(26)*x)/(x+p(27)-p(26))
          Phot=PM*(CO2i-p(26))/(p(27)-p(26))        ! Phot (mM/m^2/sec)
      END IF
      Phot=Phot*3600.0*Dlen*Mleaf*p(49)*p(3)/2.0! Phot (mM/Mcrown/day)
c p(49) is fractional % leaf surface exposed to light
      RETURN
      END
C ********************************************************************