C       4/17/2000
	SUBROUTINE Ciso (isoAll,isoC,Temp,alt,d13Ca,Ca,Ci,d13Cps,cons)
	REAL	   Ci,Ca,Cippm,d13Ca,d13Cps,r,f,CO2comp,Temp
	REAL	   DkDis,DkRt,k,vol,n,UGC,T,Pr,Cappm,isoAll(15),isoC(15)
	REAL       Cipr,Capr,cons(20)
	INTEGER	   alt
C  **************************************************************************
CC  Calculation of d13C of photosynthate using basic Farquhar equation:
CC  d13Cps = d13Ca - 4.4 * (1 - (Ci / Ca)) - 30 * (Ci/Ca)
CC  where, d13Cps is the d13C composition of tree ring photosynthate, d13Ca is
CC  the d13C composition of atmospheric CO2, -4.4 is the max. fractionation
CC  from diffusion of CO2 into leaves, -27 is the max. fractionation
CC  from the carboxylation reaction, Ci and Ca are the internal and external 
CC  concentration of CO2.
CC  CO2 conc and d13C are estimated from measurements (See: Hemming et al.,1998)
C  ***************************************************************************
	Pr=cons(7)*100 ! in kPa, 112hPa Pres. lapse rate per km
	Cippm=Ci*isoAll(2)
	Cappm=Ca*isoAll(2)
      Cipr=Cippm*(Pr/1000)
	Capr=Cappm*(Pr/1000)
	d13Cps=d13Ca+(isoC(1)*(1-(Cipr/Capr)))+(isoC(2)*(Cipr/Capr))
	RETURN
	END

	SUBROUTINE IsoResp(isoAll,isoC,what,Ca,Rsite,thick,d13Cps)
	REAL	   Sink,Ca,d13Cps,r,PhotDis,CO2comp
	REAL	   DkDis,DkRt,k,Lthick
	REAL	   RSite,MaxRSite,isoAll(15),isoC(15)
	CHARACTER*4  what
C
CC  Calculates discrimination against 13C from respiration.  Calculation is made
CC  at each location ie. leaf, stem, root after respiration is calculated.
C
	PhotDis=isoC(3) ! ppm discrimination against 13C during photorespiration (Fq et al,1982)
	CO2comp=isoC(7)/isoAll(2) ! CO2 compensation point from Farquhar, O'Leary and Berry.1982.p.137
	DkDis=isoC(4) ! ppm discrimination against 13C during dark resp. (Fq et al,1982)
	DkRt=Rsite/thick/86400 ! Rate of dark respiration (mMCO2/m2/second), 86400=sec in day
	k=isoC(8) ! Carboxylation efficiency
      IF (Rsite.LT.0.01) RETURN
	IF (what.EQ.'leaf') THEN
		r=((PhotDis*CO2comp)+((DkDis*DkRt)/k))/Ca
		ELSE
		r=(DkDis*DkRt)/k
	ENDIF
	d13Cps=d13Cps+r
	RETURN
	END

	SUBROUTINE HOisoLw(isoAll,isoO,isoH,WatProp,prec,temp,sarea,
     +sdepth,sm,p,ea,ei,dDprec,d18Oprec,dDvap,d18Ovap,dDXw,d18OXw,dDXw1,
     +d18OXw1,dDLw,d18OLw)
	REAL isoAll(15),isoO(15),isoH(15),dDLw,d18OLw,dDXw1,d18OXw1
	REAL ea,els,ei,WatProp
	REAL dHXw,d16OXw,d16Ovap
	REAL dDXw,d18OXw,d18Ovap
	REAL prec,temp,sarea,sdepth,svol,sm,p(60)
	REAL fDLw,f18Lw,tempK
	REAL dDprec,dDvap,dHvap 
C  **************************************************************************
CC  Calculation of d18O and dD
CC  dLw=lveqff*(kffda*dXw*((ei-es)/ei)+kffbl*dXw*((es-ea)/ei)+dvap*(ea/ei))
CC  dLw=dD or d18O of leaf water
CC  lveqff=liquid to vapour equilibrium fractionation factor, Majoube (1971), Clark & Fritz,p28
CC  kffda=kinetic fractionation factor of diffusion through air
CC  dXw=dD or d18O of xylem water
CC  ei=vapour pressure of intercellular air spaces, saturating Farq & Raschke 1978
CC  els=vapour pressure of leaf surface
CC  ea=vapour pressure of bulk air
CC  kffbl=kinetic fractionation factor of diffusion through boundary layer
CC  dvap=dD or d18O of atmospheric vapour
CC  sarea=soil area
CC  sdepth=soil depth
CC  svol=volume of water in soil
CC  sm=soil moisture
C  ***************************************************************************
c      f18Lw=MAX(0.7,((0.9*WatProp)+0.7)) !proxy for residence time of water in leaf
	fDLw=isoH(2)
	f18Lw=isoO(2)
	precvol=(prec/1000)*sarea
	svol=sarea*sdepth*sm
	IF (sm.LE.p(13)) THEN !Soil moisture < field capacity
	IF (prec.GT.0.0) THEN
		dDXw1=(dDXw*(svol/(precvol+svol)))+
     +						(dDprec*(precvol/(precvol+svol)))
		d18OXw1=(d18OXw*(svol/(precvol+svol)))+
     +						(d18Oprec*(precvol/(precvol+svol)))
	ELSE
		dDXw1=dDXw !Same as previous days
		d18OXw1=d18OXw
	ENDIF
	ENDIF
c	dDvap=-140.0 ! Possible constant if data not available
c	d18Ovap=-34.0 ! Possible constant if data not available
	els=ei-(isoAll(1)*ei-ea) ! Vp at leaf boundary
	tempK=temp+isoAll(3) ! Convert to Kelvin
C  Majoube 1971 equations for equilibrium liquid to vapour equilibriation fractionation @STP
	dDeqff=EXP((isoH(4)*(1000000/tempK**2)+isoH(5)*(1000/tempK)+
     +		isoH(6))/1000.0) 
	d18Oeqff=EXP((isoO(4)*(1000000/tempK**2)+isoO(5)*(1000/tempK)+
     +		isoO(6))/1000.0) 
	dDXw=isoH(7)*(1+dDXw/1000)
	dDvap=isoH(7)*(1+dDvap/1000)
	d18OXw=isoO(7)*(1+d18OXw/1000)
	d18Ovap=isoO(7)*(1+d18Ovap/1000)
C  Craig-Gordon equation of fractionation of H2O over surface of water
	dDLw=(((dDeqff*(isoH(8)*dDXw*((ei-els)/ei)+isoH(9)*
     +		dDXw*((els-ea)/ei)+dDvap*(ea/ei)))/isoH(7))-1)*1000
	d18OLw=(((d18Oeqff*(isoO(8)*d18OXw*
     +	  ((ei-els)/ei)+isoO(9)*d18OXw*
     +	  ((els-ea)/ei)+d18Ovap*(ea/ei)))/isoO(7))-1)*1000
	dDLw=dDLw*fDLw+dDXw*(1-fDLw)
	d18OLw=d18OLw*f18Lw+d18OXw*(1-f18Lw)
	dDvap=((dDvap/isoH(7))-1)*1000
	d18Ovap=((d18Ovap/isoO(7))-1)*1000
	dDXw=((dDXw/isoH(7))-1)*1000
	d18OXw=((d18OXw/isoO(7))-1)*1000
  	RETURN
	END

	SUBROUTINE HOps(isoH,isoO,dDLw,d18OLw,dDXw,d18OXw,dDps,d18Ops)
	REAL isoH(15),isoO(15),dDLw,d18OLw
	REAL d18OXw,dDXw,fDXw,f18Xw
	REAL dDps,d18Ops,dDC,d18OC
C  **************************************************************************
CC  Calculation of d18O and dD in cellulose
CC  dcell=f*(dXw+e)+(1-f)*(dLw+e)
CC  d?Lw=dD or d18O of leaf water
CC  d?Xw=dD or d18O of xylem water
CC  f=fraction of carbon-bound oxygen or hydrogen that exchanges with medium water
CC  e=fractionation of autotrophic or heterotrophic carbohydrate metabolism
C  ***************************************************************************
	fDXw=isoH(3)
	f18Xw=isoO(3)
	dDps=dDLw+isoH(10) ! dD of photosynthate exported from leaves
	d18Ops=d18OLw+isoO(10) !d18O of Photosynthate exported from leaves
	dDps=((dDXw+isoH(11))*fDXw)+(dDps*(1-fDXw)) !dD photosynthate exchanged with xylem water, same as cellulose dD
	d18Ops=(d18OXw*f18Xw)+(d18Ops*(1-f18Xw)) !d18O photosynthate exchanged with xylem water, same as cellulose d18O
	RETURN
	END