C  ****3/31/2000*******************************************************     
CC Get Values from temp/ precip data for expressing limiting conditions
C  ********************************************************************     
      REAL FUNCTION TFUNC(x,a1,a2,a3,a4)
CC
      IF(x.LE.a1)THEN
        TFUNC=0.0       ! PT - function of temperature
      ELSE IF(x.LE.a2)THEN
             TFUNC=(x-a1)/(a2-a1)
           ELSE IF(x.LE.a3)THEN
                  TFUNC=1.0
                ELSE
                  TFUNC=(a4-x)/(a4-a3)
      END IF
      IF(TFUNC.LE.0)TFUNC=0.0
      RETURN
      END


C  *******************************************************************     
CC Find whether the averaged data has reached critical value
C  *******************************************************************     
      SUBROUTINE critical(f,coef,ctime,btime,per,thresh,go,s) 
CC Subroutine calculates and returns mean value of f using weighted or 
CC unweighted moving average s - if s LE thresh go=0, if s not that go=1. 
CC f is an array of 365 values. The mean, s, is centered at ctime.
CC This prog will not calculate value until there are at least
CC values in the array from the beginning stated as btime.
CC If per is positive, average - unweighted, if negative it is weighted
CC Ctime: current time, Btime: beginning time, Coef: a positive divisor
CC scaleing weighted values (if negative it is set to value of 1). 
CC Per, Period & Iperiod: interval of average, Thresh: threshold to set
CC go to value of 1, else value of 0, S is returned as weighted average 
CC scaled by coef as divisor (as of 10/11/99 coef is always value of 1).
CC Idiog: number of weights in one tail of filter, Icenter: number
CC of central values (1 or 2), W: weights, Sum: sum of weights
      REAL       f(366),w(100)
      INTEGER    ctime, btime,option
      s=0.0
      sum=0.0
      go=0.0
      icenter=1
      coeff=coef
      IF(ctime.LT.btime)RETURN !not room for period of calc. since beg
      if(coeff.le.0.0)coeff=1.  ! divisor must be positive
      IF(per.lt.0.)then  ! Per is negative must be weighted average
        option=1         !Option 1 = weighted average
        period=abs(per)  !Changes sign of period to positive number
      ELSE               ! Per is positive not weighted average
        period=per
        option=0                   !Option 0 = unweighted average
      ENDIF
      IF(period.eq.0)period=1.0    !Converts 0 period length to 1
      IF(ctime-btime+1.LT.period)then
         period=ctime-btime+1 !Sets beginning period
      ENDIF
      iperiod=period          !creates integer
      IF(option.eq.0.or.period.eq.1.)then ! Unweighted value
         DO i=1,iperiod                     !Assign weights of 1
           w(i)=1.
         END DO
         goto 2 ! Continue
      endif
      frem=(period/2.0)-(iperiod/2)  !If frem = 0 it is an even number
      IF(frem.EQ.0.0)THEN ! Even Number
        icenter=2              !All even numbers have 2 central values
        IF(period.eq.2.)THEN
          idiog=0
          w(1)=1.                    !Assign weights to central values
          w(2)=1.
          GOTO 2  ! Continue
        ELSE
          idiog=(iperiod-2)/2
          w(idiog+1)=idiog+1         !Assign weights to central values
          w(idiog+2)=idiog+1
        ENDIF
      ELSE                ! Odd Number
        icenter=1
        idiog=(iperiod-1)/2
        w(idiog+1)=idiog+1           !Assign weight to central value
      END IF
      j=1
      DO i=1,idiog
        w(i)=j                       !Assign weights to diagonal values
        w(idiog-i+icenter+idiog+1)=j
        j=j+1
      END DO  ! Finished with odd/even number considerations
2     CONTINUE
      j=1
      DO i=ctime,ctime-iperiod+1,-1
        s=s+(f(i)*w(j))/coeff       !Calculate sum of weighted values
        sum=sum+w(j)               !Calculate sum of weights
        j=j+1
4     END DO
5     s=s/sum                      !Calculate weighted average
      IF(s.LE.thresh.AND.period.EQ.ABS(per))THEN ! Set go and Return
        go=0.0
      ELSE
        go=1.0
      END IF
      RETURN
      END
